@@ -18,6 +18,9 @@ author = 'T.Rodney (victory-k.it)'
 # The full version, including alpha/beta/rc tags
 release = check_output(['python3', '-m', 'setuptools_scm']).decode('utf-8').lstrip('v')
 
+# rst2pdf wants a version variable
+version = release
+
 
 # -- General configuration -----------------------------------------------------
 
@@ -25,7 +28,10 @@ extensions = [
     'sphinx.ext.todo',
     'sphinx.ext.autosectionlabel',
     'sphinx.ext.autodoc',
-    'sphinxarg.ext'
+    'sphinxarg.ext',
+    'sphinx.ext.autosummary',
+    'sphinx.ext.viewcode',
+    'sphinx_autodoc_typehints',
 ]
 
 templates_path = ['_templates']
@@ -61,6 +67,8 @@ if tags.has('readme'):
     master_doc = 'README'
     exclude_patterns.append('changelogs')
     exclude_patterns.append('index.rst')
+    exclude_patterns.append('python-module.rst')
+    exclude_patterns.append('_stubs')
 else:
     
     if tags.has('pdf'):
@@ -68,9 +76,9 @@ else:
         pdf_documents = [
             (
                 'index',
-                u'rst2pdf',
-                u'Sample rst2pdf doc',
-                u'Your Name'
+                f'{project}-documentation',
+                project,
+                author,
             )
         ]
 todo_include_todos = True
